`define MOD_SIZE  12				
`define MSB_MOD  (`MOD_SIZE - 1) 

/* modulator_single generates an arbitrary digital output signal.  The period of the signal is dictated by the sawtooth wave.
	The rising and falling edges within the period are controllable to create arbitrary phase/duty cycle combinations.

CONSTANTS:
	MOD_SIZE: Size of the counter register, in bits.  
	
I/O:
	sawtooth (input): digital sawtooth wave input, e.g. from sawtooth_gen block
	rising_edge (input): value of the sawtooth input counter at which the output will go high
	falling)edge (output): value of the sawtooth input counter at which the output will go low
	rst (input): reset signal; shuts down the modulator and sets the output to zero
	clk (input): clock signal.  Clock frequency determines the time resolution of the modulator.  Each increment takes one clock period
	DPWM (output): digital PWM output signal 
*/ 

module modulator_single(
    input [`MSB_MOD:0] sawtooth,
	 input [`MSB_MOD:0] rising_edge,
	 input [`MSB_MOD:0] falling_edge,
	 input rst,
    input clk,
    output DPWM
    );
	 
	reg DPWM;

	
	always @ (posedge clk or posedge rst)
	//Modulator implementation
	begin
		if (rst == 1)
			DPWM <= 0;
		else
		begin
			if (sawtooth == rising_edge)
			begin
				DPWM <= 1;
			end
			else if (sawtooth == falling_edge)
			begin
				DPWM <= 0;
			end
		end
	end
	

endmodule
