module mojo_top(
    input clk,
    input rst_n,
    input cclk,
	 output[3:0]gL,  // 4x isolated, common-ground channels
	 output[3:0]gH   // 4x independently isolated channels
    );
 
wire rst = ~rst_n;

wire clk50;
wire clk300;

//clock multiplier to get 300 MHz base clock
clkmult clkmult(
	 .clkin(clk),
    .hfclk(clk300),
    .clkout(clk50)
	 );


wire[12:0] sawtooth;

/*
*    General 8x PWM code for ECE581.  Additional details on each module can be found in comments in the individual files.
*/


//Ditial sawtooth generator.  One is shared by all modulator to ensure the sawtoothes themselves are in phase
sawtooth_gen sawtooth_gen (
	 .max_mod_value(300),
	 .rst(rst),
    .clk(clk300),
	 .sawtooth(sawtooth)
	 );

//8 individual PWM modulators.  To turn any of them off, just change 
//		.rst(rst),
//to
//		.rst(~rst),

//FPGA pin 124 
modulator_single gL0 (
	 .sawtooth(sawtooth),
	 .falling_edge(298),
	 .rising_edge(152),
	 .rst(rst),
	 .clk(clk300),
	 .DPWM(gL[0])
	 );

//FPGA pin 127
modulator_single gL1 (
	 .sawtooth(sawtooth),
	 .falling_edge(150),
	 .rising_edge(1),
	 .rst(rst),
	 .clk(clk300),
	 .DPWM(gL[1])
	 );
	 
//FPGA pin 132	 
modulator_single gL2 (
	 .sawtooth(sawtooth),
	 .falling_edge(298),
	 .rising_edge(152),
	 .rst(rst),
	 .clk(clk300),
	 .DPWM(gL[2])
	 );

//FPGA pin 124	 
modulator_single gL3 (
	 .sawtooth(sawtooth),
	 .falling_edge(150),
	 .rising_edge(1),
	 .rst(rst),
	 .clk(clk300),
	 .DPWM(gL[3])
	 );

//FPGA pin 8	 	 
modulator_single gH0 (
	 .sawtooth(sawtooth),
	 .falling_edge(298),
	 .rising_edge(152),
	 .rst(rst),
	 .clk(clk300),
	 .DPWM(gH[0])
	 );

//FPGA pin 33	 
modulator_single gH1 (
	 .sawtooth(sawtooth),
	 .falling_edge(150),
	 .rising_edge(1),
	 .rst(rst),
	 .clk(clk300),
	 .DPWM(gH[1])
	 );

//FPGA pin 92	 	 
modulator_single gH2 (
	 .sawtooth(sawtooth),
	 .falling_edge(298),
	 .rising_edge(152),
	 .rst(rst),
	 .clk(clk300),
	 .DPWM(gH[2])
	 );

//FPGA pin 120	 
modulator_single gH3 (
	 .sawtooth(sawtooth),
	 .falling_edge(150),
	 .rising_edge(1),
	 .rst(rst),
	 .clk(clk300),
	 .DPWM(gH[3])
	 );
 
endmodule