`define MOD_SIZE  12			
`define MSB_MOD  (`MOD_SIZE - 1) 				

/*Sawtooth_gen generates a digital sawtooth wave using a counter which increments with each positive edge of the
supplied clock.  The block outputs the current value of the counter.

CONSTANTS:
	MOD_SIZE: Size of the counter register, in bits.  
	
I/O:
	max_mod_value (input): constant number which is the maximum digital value the counter will reach before looping back to zero.
		max_mod_value < 2^MOD_SIZE
	rst (input): reset signal; shuts down the counter and sets the sawtooth wave to zero
	clk (input): clock signal.  Clock frequency determines the time resolution of the modulator.  Each increment takes one clock period
	sawtooth (output): counter register output.  The sawtooth register value will increment every clock period, and will loop back to zero
		when the register value reaches max_mod_value.  
*/ 
module sawtooth_gen(
	 input [`MSB_MOD:0] max_mod_value,
	 input rst,
    input clk,
    output [`MSB_MOD:0] sawtooth
    );
	 
	reg [`MSB_MOD:0] sawtooth;
	
	always @ (posedge clk or posedge rst)
	//counter implementation
	begin
		if (rst == 1)
			sawtooth <= 0;
		else
		begin
			sawtooth <= (sawtooth > max_mod_value-2) ? 0 : sawtooth+1;	 //increment/loop modulator
			//Note: subtract two from max_mod_value to account for 1 clock for the comparison and 1 clock to return to zero.
		end
	end

endmodule
